@@ -597,6 +597,16 @@ extern const lookup_info ml_table_tree_model_flags[];
 #define Val_tree_model_flags(data) ml_lookup_from_c (ml_table_tree_model_flags, data)
 #define Tree_model_flags_val(key) ml_lookup_to_c (ml_table_tree_model_flags, key)
 
+/* tree_view_drop_position : tags and macros */
+#define MLTAG_BEFORE	((value)(-860553089*2+1))
+#define MLTAG_AFTER	((value)(462462460*2+1))
+#define MLTAG_INTO_OR_BEFORE	((value)(486315964*2+1))
+#define MLTAG_INTO_OR_AFTER	((value)(-475234977*2+1))
+
+extern const lookup_info ml_table_tree_view_drop_position[];
+#define Val_tree_view_drop_position(data) ml_lookup_from_c (ml_table_tree_view_drop_position, data)
+#define Tree_view_drop_position_val(key) ml_lookup_to_c (ml_table_tree_view_drop_position, key)
+
 /* file_filter_flags : tags and macros */
 #define MLTAG_FILENAME	((value)(-789594425*2+1))
 #define MLTAG_URI	((value)(4245324*2+1))
